==> pipewire-docs-1%3A0.3.32-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/build_2doc_2spa_2support_2log_8h.js <==
var build_2doc_2spa_2support_2log_8h =
[
    [ "SPA_KEY_LOG_COLORS", "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e", null ],
    [ "SPA_KEY_LOG_FILE", "group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a", null ],
    [ "SPA_KEY_LOG_LEVEL", "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6", null ],
    [ "SPA_KEY_LOG_LINE", "group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018", null ],
    [ "SPA_KEY_LOG_TIMESTAMP", "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14", null ],
    [ "spa_log_debug", "group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72", null ],
    [ "spa_log_error", "group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4", null ],
    [ "spa_log_info", "group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6", null ],
    [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
    [ "spa_log_log", "group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2", null ],
    [ "spa_log_logv", "group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db", null ],
    [ "spa_log_trace", "group__spa__log.html#ga142802024be8a40bef345806d498d6b6", null ],
    [ "spa_log_trace_fp", "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8", null ],
    [ "spa_log_warn", "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620", null ],
    [ "SPA_TYPE_INTERFACE_Log", "group__spa__log.html#gaae4067126110801d47890be91be83c5e", null ],
    [ "SPA_VERSION_LOG", "group__spa__log.html#gab60b078a5687f091f11d951899e7c270", null ],
    [ "SPA_VERSION_LOG_METHODS", "build_2doc_2spa_2support_2log_8h.html#a750a6ac2af9bf84c4b59af14d6cbe22f", null ],
    [ "spa_log_level", "group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d", [
      [ "SPA_LOG_LEVEL_NONE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd", null ],
      [ "SPA_LOG_LEVEL_ERROR", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114", null ],
      [ "SPA_LOG_LEVEL_WARN", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64", null ],
      [ "SPA_LOG_LEVEL_INFO", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f", null ],
      [ "SPA_LOG_LEVEL_DEBUG", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034", null ],
      [ "SPA_LOG_LEVEL_TRACE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662", null ]
    ] ]
];

==> pipewire-docs-1%3A0.3.33-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/build_2doc_2spa_2support_2log_8h.js <==
var build_2doc_2spa_2support_2log_8h =
[
    [ "SPA_KEY_LOG_COLORS", "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e", null ],
    [ "SPA_KEY_LOG_FILE", "group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a", null ],
    [ "SPA_KEY_LOG_LEVEL", "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6", null ],
    [ "SPA_KEY_LOG_LINE", "group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018", null ],
    [ "SPA_KEY_LOG_TIMESTAMP", "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14", null ],
    [ "spa_log_debug", "group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72", null ],
    [ "spa_log_error", "group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4", null ],
    [ "spa_log_info", "group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6", null ],
    [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
    [ "spa_log_log", "group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2", null ],
    [ "spa_log_logv", "group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db", null ],
    [ "spa_log_trace", "group__spa__log.html#ga142802024be8a40bef345806d498d6b6", null ],
    [ "spa_log_trace_fp", "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8", null ],
    [ "spa_log_warn", "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620", null ],
    [ "SPA_TYPE_INTERFACE_Log", "group__spa__log.html#gaae4067126110801d47890be91be83c5e", null ],
    [ "SPA_VERSION_LOG", "build_2doc_2spa_2support_2log_8h.html#ab60b078a5687f091f11d951899e7c270", null ],
    [ "SPA_VERSION_LOG_METHODS", "build_2doc_2spa_2support_2log_8h.html#a750a6ac2af9bf84c4b59af14d6cbe22f", null ],
    [ "spa_log_level", "group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d", [
      [ "SPA_LOG_LEVEL_NONE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd", null ],
      [ "SPA_LOG_LEVEL_ERROR", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114", null ],
      [ "SPA_LOG_LEVEL_WARN", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64", null ],
      [ "SPA_LOG_LEVEL_INFO", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f", null ],
      [ "SPA_LOG_LEVEL_DEBUG", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034", null ],
      [ "SPA_LOG_LEVEL_TRACE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662", null ]
    ] ]
];
